crstools-package: crstools: Tools to Work with Projections

crstools-packageR Documentation

crstools: Tools to Work with Projections

Description

Choose the appropriate map projection for a given application, visualise the resulting distortion, and georeference data from unknown projections. The full functionalities of the package are described in Pozzi et al. (2026) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.31223/X5K17P")} (pre-print).

Author(s)

Maintainer: Andrea Manica am315@cam.ac.uk (ORCID)

Authors:

  • Andrea Pozzi

  • Cecilia Padilla-Iglesias

  • Evie Carter

  • Michela Leonardi

  • Aramish Fatima

  • Ondrej Pelanek

  • Nile Stephenson

  • Margherita Colucci

  • Dominik C Jud

  • Cassandra Gunasekaram


crstools documentation built on March 19, 2026, 5:08 p.m.