| crstools-package | R Documentation |
Choose the appropriate map projection for a given application, visualise the resulting distortion, and georeference data from unknown projections. The full functionalities of the package are described in Pozzi et al. (2026) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.31223/X5K17P")} (pre-print).
Maintainer: Andrea Manica am315@cam.ac.uk (ORCID)
Authors:
Andrea Pozzi
Cecilia Padilla-Iglesias
Evie Carter
Michela Leonardi
Aramish Fatima
Ondrej Pelanek
Nile Stephenson
Margherita Colucci
Dominik C Jud
Cassandra Gunasekaram
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.